Name:           ndoutils
Version:        1.5.2

Release:        1%{?dist}
Summary:        Stores all configuration and event data from Nagios in a database
Group:          Applications/System
License:        GPLv2
URL:            http://www.nagios.org/download/addons/
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

Source0:        http://downloads.sourceforge.net/nagios/ndoutils-%{version}.tar.gz
Source1:        README.Fedora
Source2:        ndo2db.cfg 
Source3:        ndomod.cfg
Source4:        ndo2db.service
Source5:        ndo2db.init
Patch0:         ndo-shared-so.patch

BuildRequires:  mysql-devel

# Nagios is required also for user and group
%if 0%{?rhel} == 5
Requires:       nagios < 3
%else
Requires:       nagios >= 3
%endif

%if 0%{?fedora} || 0%{?rhel} >= 7
Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd
%endif

%if 0%{?rhel} == 5 || 0%{?rhel} == 6
Requires(post):     /sbin/chkconfig
Requires(preun):    /sbin/chkconfig
Requires(preun):    /sbin/service
Requires(postun):   /sbin/service
%endif

%description
The NDOUtils add on is designed to store all configuration and event data from
Nagios in a database. Storing information from Nagios in a database will allow
for quicker retrieval and processing of that data.

%package        mysql
Summary:        Contains the NDOUtils ndo2db for MySQL
Group:          Applications/System
Requires:       ndoutils = %{version}-%{release}

%description    mysql
Contains an ndo2db for writing ndoutils data from Nagios to MySQL.


%prep
%setup -q
%patch0 -p1

# Remove executable bits from the example scripts in 
# the documentation.
chmod 644 db/installdb db/prepsql db/upgradedb


%build
%configure 
make %{?_smp_mflags}
%if 0%{?rhel} == 5
cp -p src/ndo2db-2x src/ndo2db.mysql
%else
cp -p src/ndo2db-3x src/ndo2db.mysql
%endif

%install
rm -rf %{buildroot}
install -p -m 644 %{SOURCE1} README.Fedora

# Perform a manual install, we rely on main Nagios package (user, group, etc.)
%if 0%{?rhel} == 5
install -p -m 755 -D src/ndomod-2x.so %{buildroot}%{_libdir}/nagios/brokers/ndomod.so
%else
install -p -m 755 -D src/ndomod-3x.so %{buildroot}%{_libdir}/nagios/brokers/ndomod.so
%endif

install -p -m 755 -D src/ndo2db.mysql %{buildroot}%{_sbindir}/ndo2db.mysql
install -p -m 644 -D %{SOURCE2} %{buildroot}%{_sysconfdir}/nagios/ndo2db.cfg
install -p -m 644 -D %{SOURCE3} %{buildroot}%{_sysconfdir}/nagios/ndomod.cfg
mkdir -p %{buildroot}%{_localstatedir}/log/ndoutils
mkdir -p %{buildroot}%{_localstatedir}/run/ndoutils
mkdir -p %{buildroot}%{_localstatedir}/cache/ndoutils

# Remove some spurious permissions from docs
find docs/html -name "*.*" -exec chmod 644 {} \;

%if 0%{?fedora} || 0%{?rhel} >= 7

# Systemd unit files
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 -D %{SOURCE4} %{buildroot}%{_unitdir}/ndo2db.service

%else

# Initscripts
mkdir -p %{buildroot}%{_initrddir}
install -p -m 755 -D %{SOURCE5} %{buildroot}%{_initrddir}/ndo2db

%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc README.Fedora docs/html README REQUIREMENTS TODO UPGRADING
%config(noreplace) %{_sysconfdir}/nagios/ndo2db.cfg
%config(noreplace) %{_sysconfdir}/nagios/ndomod.cfg
%{_libdir}/nagios/brokers/ndomod.so
%if 0%{?fedora} || 0%{?rhel} >= 7
%{_unitdir}/ndo2db.service
%else
%{_initrddir}/ndo2db
%endif
%dir %attr(-,nagios,root) %{_localstatedir}/run/ndoutils
%dir %attr(-,nagios,root) %{_localstatedir}/log/ndoutils
%dir %attr(-,nagios,root) %{_localstatedir}/cache/ndoutils

%files mysql
%defattr(-,root,root,-)
%{_sbindir}/ndo2db.mysql
%doc db

%if 0%{?fedora} || 0%{?rhel} >= 7

%post
%systemd_post ndo2db.service

%preun
%systemd_preun ndo2db.service

%postun
%systemd_postun_with_restart ndo2db.service

%endif

%if 0%{?rhel} == 6

%post
/sbin/chkconfig --add ndo2db

%preun
if [ "$1" = 0 ]; then
        /sbin/service ndo2db stop >/dev/null 2>&1 || :
        /sbin/chkconfig --del ndo2db
fi

%postun
if [ "$1" -ge "1" ]; then
        /sbin/service ndo2db condrestart >/dev/null 2>&1 || :
fi

%endif

%post mysql
/usr/sbin/alternatives --install /usr/sbin/ndo2db ndo2db /usr/sbin/ndo2db.mysql 40

%changelog
* Mon Feb 24 2014 Simone Caronni <negativo17@gmail.com> - 1.5.2-1
- Updated to 1.5.2.
- Updated SPEC file for current packaging guidelines.
- Use only generated docs for binary package.

* Wed Nov 11 2009 Steve Traylen <tmraz@redhat.com> - 1.4-0.7.b9
- New upstream version. 1.4b9

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 1.4-0.7.b8
- rebuilt with new openssl

* Tue Jul 21 2009 Steve Traylen <steve.traylen@cern.ch> - 1.4-0.6.b8
- A requires nagios = 2 will not work.

* Tue Jul 21 2009 Steve Traylen <steve.traylen@cern.ch> - 1.4-0.5.b8
- Updated to nodutils 1.4b8.
- mysql lib path no longer needs to be set explicitly.
- Use dist tags to install for nagios2 on el4 and el5.

* Mon Jul 20 2009 Steve Traylen <steve.traylen@cern.ch> - 1.4-0.4.b7
- Patch ndomod.o to be ndomod.so since it is a shared object.
- Move ndomod.so from /usr/lib to /usr/lib/nagios/brokers
- Change URL to better one.
- Change SourceURL to fedora package guideline for sourceforge.
- Completly removed postgres support. The documents clearly state
  it is not supported.

* Sun Jun 14 2009 Steve Traylen <steve@traylen.net> - 1.4-0.3.b7
- Move ndo2db.cfg and ndomod.cfg to /etc/nagios as per install
  guide.
- Remove executable bits from documentation examples.

* Thu Jun 11 2009 Steve Traylen <steve@traylen.net> - 1.4-0.2.b7
- Split package to create postgres and mysql binary in different
  sub packages.

* Wed Jun 10 2009 Steve Traylen <steve@traylen.net> - 1.4-0.1.b7
- Add full URL location to Source0:
- Use special Version/Release tag since a beta. i.e 1.4-0.1.b7

* Sat Apr 25 2009 Steve Traylen <steve@traylen.net> 
- First Build
